==> sns-1.32.0-sources.jar: software/amazon/awscdk/services/sns/SubscriptionFilter.java <==
package software.amazon.awscdk.services.sns;

/**
 * A subscription filter for an attribute.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.1.0 (build df55f5e)", date = "2020-04-07T12:30:30.507Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sns.$Module.class, fqn = "@aws-cdk/aws-sns.SubscriptionFilter")
public class SubscriptionFilter extends software.amazon.jsii.JsiiObject {

    protected SubscriptionFilter(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SubscriptionFilter(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param conditions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SubscriptionFilter(final @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> conditions) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { conditions });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SubscriptionFilter() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Returns a subscription filter for attribute key matching.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.SubscriptionFilter existsFilter() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.sns.SubscriptionFilter.class, "existsFilter", software.amazon.awscdk.services.sns.SubscriptionFilter.class);
    }

    /**
     * Returns a subscription filter for a numeric attribute.
     * <p>
     * @param numericConditions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.SubscriptionFilter numericFilter(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.NumericConditions numericConditions) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.sns.SubscriptionFilter.class, "numericFilter", software.amazon.awscdk.services.sns.SubscriptionFilter.class, new Object[] { java.util.Objects.requireNonNull(numericConditions, "numericConditions is required") });
    }

    /**
     * Returns a subscription filter for a string attribute.
     * <p>
     * @param stringConditions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.SubscriptionFilter stringFilter(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.StringConditions stringConditions) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.sns.SubscriptionFilter.class, "stringFilter", software.amazon.awscdk.services.sns.SubscriptionFilter.class, new Object[] { java.util.Objects.requireNonNull(stringConditions, "stringConditions is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.Object> getConditions() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("conditions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
    }
}

==> sns-1.60.0-sources.jar: software/amazon/awscdk/services/sns/SubscriptionFilter.java <==
package software.amazon.awscdk.services.sns;

/**
 * A subscription filter for an attribute.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:13.461Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sns.$Module.class, fqn = "@aws-cdk/aws-sns.SubscriptionFilter")
public class SubscriptionFilter extends software.amazon.jsii.JsiiObject {

    protected SubscriptionFilter(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SubscriptionFilter(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param conditions conditions that specify the message attributes that should be included, excluded, matched, etc.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SubscriptionFilter(final @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> conditions) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { conditions });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SubscriptionFilter() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Returns a subscription filter for attribute key matching.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.SubscriptionFilter existsFilter() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.sns.SubscriptionFilter.class, "existsFilter", software.amazon.awscdk.services.sns.SubscriptionFilter.class);
    }

    /**
     * Returns a subscription filter for a numeric attribute.
     * <p>
     * @param numericConditions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.SubscriptionFilter numericFilter(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.NumericConditions numericConditions) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.sns.SubscriptionFilter.class, "numericFilter", software.amazon.awscdk.services.sns.SubscriptionFilter.class, new Object[] { java.util.Objects.requireNonNull(numericConditions, "numericConditions is required") });
    }

    /**
     * Returns a subscription filter for a string attribute.
     * <p>
     * @param stringConditions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.SubscriptionFilter stringFilter(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.StringConditions stringConditions) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.sns.SubscriptionFilter.class, "stringFilter", software.amazon.awscdk.services.sns.SubscriptionFilter.class, new Object[] { java.util.Objects.requireNonNull(stringConditions, "stringConditions is required") });
    }

    /**
     * conditions that specify the message attributes that should be included, excluded, matched, etc.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.Object> getConditions() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("conditions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
    }
}
